# -*- coding: utf-8 -*-
"""
Created on Thu Jan 10 08:43:11 2019

@author: Machacek
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib import cm
from matplotlib import gridspec
import os
import itertools

plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'

plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['font.size'] = 10
plt.rcParams['text.usetex'] = True
plt.rcParams['text.color'] = 'black'
plt.rcParams['axes.spines.top'] = False
plt.rcParams['axes.spines.right'] = False
# ----------------------------------------------
# -----------------------------------------------------------------------------
# Color definitions (RGB)
# -----------------------------------------------------------------------------
                        
# Color schemes generated with "internal" color maps          
start = 0.0
stop = 1.0
number_of_lines= 6
mytextwidth=13.6
coolwarm = [ cm.coolwarm(x) for x in np.linspace(start, stop, number_of_lines)  ]


# -----------------------------------------------------------------------------
# Functions / Definitions
# -----------------------------------------------------------------------------
def cm2inch(*tupl):
    inch = 2.54
    if isinstance(tupl[0], tuple):
        return tuple(i/inch for i in tupl[0])
    else:
        return tuple(i/inch for i in tupl)

# -----------------------------------------------------------------------------
# Enter folder names
# -----------------------------------------------------------------------------
    
folder_list_2D = ['non_aligned_EBM_u-print-out','non_aligned_SBM_u_print_output'
                 ,'mesh_tri-print-out' ,'mesh_tri_non_aligned-print-out']
names =['Quad mesh', 'Quad mesh', 'Tri mesh - conform', 'Tri mesh - non conform']

nfolders = len(folder_list_2D) 

# =============================================================================
# 
# =============================================================================
Radius=1./8 + 1./8
Radius=1./Radius
nu=0.3
emod=(1.-nu**2) /200. + (1.-nu**2) /200.
emod=1./emod
Force = 10


eindringtiefe = (4.*Force/(np.pi*emod))
a=np.sqrt(Radius*eindringtiefe)
p0 = 2*Force/(np.pi *a)


p=[]
f=[]
Coords=np.arange(0,1,0.001)
for coord in Coords:
    if (1.-coord*coord/a/a)<0:
        break
    pressure=p0*(1.-coord*coord/a/a)**0.5
    p.append(pressure)
    f.append(coord)

p_val = [x for x in p]
x_val = [x for x in f]


    
# =============================================================================
#     
# =============================================================================

# -----------------------------------------------------------------------------
# Plotting ranges
# -----------------------------------------------------------------------------

xmax = 60.
xmin = 0.0
ymax = 1.

# Begin figure
fig = plt.figure(figsize=cm2inch(18,9*nfolders)) 

# Set the layout of the subplots
gs = gridspec.GridSpec(nfolders,2)

time_steps = [0.05,0.1,1,10,100,1000,10000]
label_time_steps = ['$t = 5 \cdot10^{-2}$ s','$t = 10^{-1}$ s','$t = 10^{9}$ s',\
                    '$t = 10^{1}$ s','$t = 10^2$ s','$t = 10^3$ s','$t = 10^4$ s']


i = 0
count = 0
file_count = 0
for name in itertools.chain(folder_list_2D):

    last_coords = []
    last_stress  = []
    last_stressy =  []

# =============================================================================
# Get all data files for each calculation and store them in vertical_coords and pore_pressure
# =============================================================================
    if(file_count>len(folder_list_2D)):
        
        for filename in os.listdir(os.getcwd()+'/'+name+ '/'+'Hertz3D_lin_print_output'):
            stress = []
            coords = []
            if(filename[0:4] == 'SOIL'):
                stress = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D_lin_print_output/' + filename, skip_header=1, skip_footer=0, usecols=4)
                coords = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D_lin_print_output/' + filename, skip_header=1, skip_footer=0, usecols=2)
                time = np.genfromtxt(os.getcwd()+'/'+name+ '/'+'Hertz3D_lin_print_output/' + filename, skip_header=1, skip_footer=0, usecols=0) -1.
                
                
                last_coords.append(coords[-1])
                last_stress.append(stress[-1])
    else:
        for filename in os.listdir(os.getcwd()+'/'+name+ '/'):
            stress = []
            coords = []
            
            stress = np.genfromtxt(os.getcwd()+'/'+name+ '/'+ filename, skip_header=1, skip_footer=0, usecols=4)
            stressy = np.genfromtxt(os.getcwd()+'/'+name+ '/'+ filename, skip_header=1, skip_footer=0, usecols=5)
            coords = np.genfromtxt(os.getcwd()+'/'+name+ '/'+ filename, skip_header=1, skip_footer=0, usecols=1)
            time = np.genfromtxt(os.getcwd()+'/'+name+ '/' + filename, skip_header=1, skip_footer=0, usecols=0) -1.
            
            
            last_coords.append(coords[-1])
            last_stress.append(stress[-1])
            last_stressy.append(stressy[-1])
    count = 0
# =============================================================================
# Now plot data for each time step for all nodes/elements along the height
# =============================================================================
    indeces = [u[0] for u in sorted(enumerate(last_coords), key=lambda x:x[1])]
    local_stress = []
    local_coords =[]
    local_stressy =[]
    local_coords = sorted(last_coords,reverse=False)

    for x in range(len(last_stress)):
        scalar = last_stress[indeces[x]]
        local_stress.append(scalar)
        scalar = last_stressy[indeces[x]]
        local_stressy.append(scalar)

# =============================================================================
# Plot displacement
# =============================================================================
    if(file_count == 1):
        plt.subplot(gs[i])
        plt.title(names[i],fontsize=13)
        plt.plot(local_coords,local_stress,'bo-', lw=0.75, label='segment-based\nmortar',
                  markersize=6,markerfacecolor='none',markevery=1,
                  clip_on=True)
        #plt.plot(local_coords,local_stressy,'r', lw=0.75)
        plt.plot(x_val,p_val,'-r', linewidth=2.0, markersize=6,markerfacecolor='none',\
                        label='Analytical',clip_on=False,alpha=1.0)
        plt.xlim(0.0,0.8)
        plt.ylim(0,10.)
        plt.xlabel('Distance from symmetry axis $x$ [m]' ,fontsize=mytextwidth,labelpad=4)
        plt.ylabel('Normal contact stress $t_{N}$ [kPa]',fontsize=mytextwidth,labelpad=4)
        legend=plt.legend(bbox_to_anchor=(0.4, 0.15), loc='center',fontsize=mytextwidth-0.6,ncol=1,\
                 handletextpad=0.5,borderaxespad=.03,labelspacing=0, handlelength = 1.8,columnspacing=.8)
        frame=legend.get_frame()
        frame.set_edgecolor('white')
        frame.set_facecolor('white')
        legend.get_frame().set_alpha(1)
        #plt.tick_params(labelcolor='k', top='on', bottom='on', left='on', right='on',\
        #                labelsize=mytextwidth,direction='in',pad=7)
        #plt.grid(True)
    else:
        plt.subplot(gs[i])
        plt.title(names[i],fontsize=13)
        plt.plot(local_coords,local_stress,'bo-', lw=0.75, label='element-based\nmortar',
                  markersize=6,markerfacecolor='none',markevery=1,
                  clip_on=True)
        #plt.plot(local_coords,local_stressy,'r', lw=0.75)
        plt.plot(x_val,p_val,'-r', linewidth=2.0, markersize=6,markerfacecolor='none',\
                        label='Analytical',clip_on=False,alpha=1.0)
        plt.xlim(0.0,0.8)
        plt.ylim(0,10.)
        plt.xlabel('Distance from symmetry axis $x$ [m]' ,fontsize=mytextwidth,labelpad=4)
        plt.ylabel('Normal contact stress $t_{N}$ [kPa]',fontsize=mytextwidth,labelpad=4)
        #plt.tick_params(labelcolor='k', top='on', bottom='on', left='on', right='on',\
        #                labelsize=mytextwidth,direction='in',pad=7)
        legend=plt.legend(bbox_to_anchor=(0.39, 0.15), loc='center',fontsize=mytextwidth-0.6,ncol=1,\
                 handletextpad=0.5,borderaxespad=.03,labelspacing=0, handlelength = 1.8,columnspacing=.8)
        frame=legend.get_frame()
        frame.set_edgecolor('white')
        frame.set_facecolor('white')
        legend.get_frame().set_alpha(1)

        #plt.grid(True)
    i = i + 1
    file_count += 1


plt.tight_layout(w_pad=1.5)
plt.show()

fig.savefig('hertz_comparison.pdf',dpi=1200 ,bbox_inches='tight')

fig.savefig('hertz_comparison.png',dpi=1200 , bbox_inches='tight')
#fig.savefig('terzaghi_comparison.svg', bbox_inches='tight')
